@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 12748 2021-02-06 05:31:58Z Casey $
+# $Id: admin.py 13367 2021-12-24 04:53:31Z Mint $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Casey $
-# $Date: 2021-02-06 13:31:58 +0800 (週六, 06 二月 2021) $
-# $Revision: 12748 $
+# $Author: Mint $
+# $Date: 2021-12-24 12:53:31 +0800 (週五, 24 十二月 2021) $
+# $Revision: 13367 $
 
 import os
 import datetime
@@ -28,7 +28,6 @@ from django import forms
 from django.conf import settings
 from django.utils.html import mark_safe
 from django.utils.translation import ugettext_lazy as _
-from django.contrib.admin.templatetags.admin_static import static
 from django.contrib.auth.signals import user_logged_in
 from django.forms import Media
 from django.db import transaction
